Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CagipV1Client ¶
type CagipV1Client struct {
// contains filtered or unexported fields
}
CagipV1Client is used to interact with features provided by the cagip.github.com group.
func New ¶
func New(c rest.Interface) *CagipV1Client
New creates a new CagipV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*CagipV1Client, error)
NewForConfig creates a new CagipV1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new CagipV1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *CagipV1Client
NewForConfigOrDie creates a new CagipV1Client for the given config and panics if there is an error in the config.
func (*CagipV1Client) RESTClient ¶
func (c *CagipV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*CagipV1Client) ResourceQuotaClaims ¶
func (c *CagipV1Client) ResourceQuotaClaims(namespace string) ResourceQuotaClaimInterface
type CagipV1Interface ¶
type CagipV1Interface interface {
RESTClient() rest.Interface
ResourceQuotaClaimsGetter
}
type ResourceQuotaClaimExpansion ¶
type ResourceQuotaClaimExpansion interface{}
type ResourceQuotaClaimInterface ¶
type ResourceQuotaClaimInterface interface {
Create(ctx context.Context, resourceQuotaClaim *v1.ResourceQuotaClaim, opts metav1.CreateOptions) (*v1.ResourceQuotaClaim, error)
Update(ctx context.Context, resourceQuotaClaim *v1.ResourceQuotaClaim, opts metav1.UpdateOptions) (*v1.ResourceQuotaClaim, error)
UpdateStatus(ctx context.Context, resourceQuotaClaim *v1.ResourceQuotaClaim, opts metav1.UpdateOptions) (*v1.ResourceQuotaClaim, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.ResourceQuotaClaim, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.ResourceQuotaClaimList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.ResourceQuotaClaim, err error)
ResourceQuotaClaimExpansion
}
ResourceQuotaClaimInterface has methods to work with ResourceQuotaClaim resources.
type ResourceQuotaClaimsGetter ¶
type ResourceQuotaClaimsGetter interface {
ResourceQuotaClaims(namespace string) ResourceQuotaClaimInterface
}
ResourceQuotaClaimsGetter has a method to return a ResourceQuotaClaimInterface. A group's client should implement this interface.