Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ResourceQuotaClaimLister ¶
type ResourceQuotaClaimLister interface {
// List lists all ResourceQuotaClaims in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.ResourceQuotaClaim, err error)
// ResourceQuotaClaims returns an object that can list and get ResourceQuotaClaims.
ResourceQuotaClaims(namespace string) ResourceQuotaClaimNamespaceLister
ResourceQuotaClaimListerExpansion
}
ResourceQuotaClaimLister helps list ResourceQuotaClaims. All objects returned here must be treated as read-only.
func NewResourceQuotaClaimLister ¶
func NewResourceQuotaClaimLister(indexer cache.Indexer) ResourceQuotaClaimLister
NewResourceQuotaClaimLister returns a new ResourceQuotaClaimLister.
type ResourceQuotaClaimListerExpansion ¶
type ResourceQuotaClaimListerExpansion interface{}
ResourceQuotaClaimListerExpansion allows custom methods to be added to ResourceQuotaClaimLister.
type ResourceQuotaClaimNamespaceLister ¶
type ResourceQuotaClaimNamespaceLister interface {
// List lists all ResourceQuotaClaims in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.ResourceQuotaClaim, err error)
// Get retrieves the ResourceQuotaClaim from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.ResourceQuotaClaim, error)
ResourceQuotaClaimNamespaceListerExpansion
}
ResourceQuotaClaimNamespaceLister helps list and get ResourceQuotaClaims. All objects returned here must be treated as read-only.
type ResourceQuotaClaimNamespaceListerExpansion ¶
type ResourceQuotaClaimNamespaceListerExpansion interface{}
ResourceQuotaClaimNamespaceListerExpansion allows custom methods to be added to ResourceQuotaClaimNamespaceLister.
Click to show internal directories.
Click to hide internal directories.